==> ejc-salary-impl-3.0.0-20241129.064655-72-sources.jar: com/ejianc/business/salary/bean/PayableDetailEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发工资上传明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_payable_detail")
public class PayableDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="payable_id")
    private Long payableId; // 主表id
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 员工主键
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 员工名称
    @TableField(value="detail_employee_code")
    private String detailEmployeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="job_type")
    private String jobType; // 岗位性质
    @TableField(value="detail_org_id")
    private Long detailOrgId; // 单位id
    @TableField(value="detail_org_name")
    private String detailOrgName; // 单位名称
    @TableField(value="detail_org_code")
    private String detailOrgCode; // 单位编码
    @TableField(value="job")
    private String job; // 岗位
    @TableField(value="dept")
    private String dept; // 部门
    @TableField(value="job_level")
    private String jobLevel; // 岗级
    @TableField(value="sbjn_org_name")
    private String sbjnOrgName; // 社保缴纳单位名称
    @TableField(value="sbjn_org_code")
    private String sbjnOrgCode; // 社保缴纳单位编码
    @TableField(value="is_move")
    private String isMove; // 本月是否发生调动：1是,2-否
    @TableField(value="sbcd_org_id")
    private Long sbcdOrgId; // 社保承担单位id
    @TableField(value="sbcd_org_name")
    private String sbcdOrgName; // 社保承担单位名称
    @TableField(value="sbcd_org_code")
    private String sbcdOrgCode; // 社保承担单位编码
    @TableField(value="gzff_org_id")
    private Long gzffOrgId; // 工资发放单位id
    @TableField(value="gzff_org_name")
    private String gzffOrgName; // 工资发放单位名称
    @TableField(value="gzff_org_code")
    private String gzffOrgCode; // 工资发放单位编码
    @TableField(value="un_write_off_mny")
    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    @TableField(value="write_off_mny")
    private BigDecimal writeOffMny; // 本次核销金额
    @TableField(value="yfjs_mny")
    private BigDecimal yfjsMny; // 应发计税
    @TableField(value="yfms_mny")
    private BigDecimal yfmsMny; // 应发免税
    @TableField(value="job_mny")
    private BigDecimal jobMny; // 岗位工资
    @TableField(value="performance_mny")
    private BigDecimal performanceMny; // 绩效工资
    @TableField(value="work_year_mny")
    private BigDecimal workYearMny; // 司龄补贴
    @TableField(value="work_type_mny")
    private BigDecimal workTypeMny; // 职称补贴
    @TableField(value="certificate_mny")
    private BigDecimal certificateMny; // 证书补贴
    @TableField(value="travel_mny")
    private BigDecimal travelMny; // 派驻补贴
    @TableField(value="traffic_mny")
    private BigDecimal trafficMny; // 交通补贴
    @TableField(value="meal_mny")
    private BigDecimal mealMny; // 餐补
    @TableField(value="benefit_mny")
    private BigDecimal benefitMny; // 福利费
    @TableField(value="holiday_mny")
    private BigDecimal holidayMny; // 过节费
    @TableField(value="year_end_mny")
    private BigDecimal yearEndMny; // 年终奖
    @TableField(value="overtime_mny")
    private BigDecimal overtimeMny; // 加班费
    @TableField(value="add_mny")
    private BigDecimal addMny; // 补款
    @TableField(value="button_mny")
    private BigDecimal buttonMny; // 扣款
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 工资合计
    @TableField(value="yf_salary_mny")
    private BigDecimal yfSalaryMny; // 应发工资
    @TableField(value="yfms_salary_mny")
    private BigDecimal yfmsSalaryMny; // 应发+免税
    @TableField(value="org_salary_mny")
    private BigDecimal orgSalaryMny; // 个人本单位累计
    @TableField(value="orgs_salary_mny")
    private BigDecimal orgsSalaryMny; // 个人所有单位累计
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="tax_yfms_mny")
    private BigDecimal taxYfmsMny; // 个税计算、工资单应发免税

    @TableField(value="detail_collect_status")
    private Integer detailCollectStatus; // 汇总状态（0-未汇总，1--已汇总,2-被驳回）

    @TableField(value="sbcd_company_id")
    private Long sbcdCompanyId; // 社保承担公司id
    @TableField(value="sbcd_company_code")
    private String sbcdCompanyCode; // 社保承担公司编号
    @TableField(value="sbcd_company_name")
    private String sbcdCompanyName; // 社保承担公司

    @TableField(value="yfjscw_mny")
    private BigDecimal yfjscwMny; // 应发计税财务
    @TableField(value="yfmscw_mny")
    private BigDecimal yfmscwMny; // 应发免税财务


    public BigDecimal getYfjscwMny() {
        return yfjscwMny;
    }

    public void setYfjscwMny(BigDecimal yfjscwMny) {
        this.yfjscwMny = yfjscwMny;
    }

    public BigDecimal getYfmscwMny() {
        return yfmscwMny;
    }

    public void setYfmscwMny(BigDecimal yfmscwMny) {
        this.yfmscwMny = yfmscwMny;
    }

    public Long getSbcdCompanyId() {
        return sbcdCompanyId;
    }

    public void setSbcdCompanyId(Long sbcdCompanyId) {
        this.sbcdCompanyId = sbcdCompanyId;
    }

    public String getSbcdCompanyCode() {
        return sbcdCompanyCode;
    }

    public void setSbcdCompanyCode(String sbcdCompanyCode) {
        this.sbcdCompanyCode = sbcdCompanyCode;
    }

    public String getSbcdCompanyName() {
        return sbcdCompanyName;
    }

    public void setSbcdCompanyName(String sbcdCompanyName) {
        this.sbcdCompanyName = sbcdCompanyName;
    }

    public Integer getDetailCollectStatus() {
        return detailCollectStatus;
    }

    public void setDetailCollectStatus(Integer detailCollectStatus) {
        this.detailCollectStatus = detailCollectStatus;
    }

    public Long getPayableId() {
        return payableId;
    }

    public void setPayableId(Long payableId) {
        this.payableId = payableId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getJobType() {
        return jobType;
    }

    public void setJobType(String jobType) {
        this.jobType = jobType;
    }
    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }
    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }
    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getDept() {
        return dept;
    }

    public void setDept(String dept) {
        this.dept = dept;
    }
    public String getJobLevel() {
        return jobLevel;
    }

    public void setJobLevel(String jobLevel) {
        this.jobLevel = jobLevel;
    }
    public String getSbjnOrgName() {
        return sbjnOrgName;
    }

    public void setSbjnOrgName(String sbjnOrgName) {
        this.sbjnOrgName = sbjnOrgName;
    }
    public String getSbjnOrgCode() {
        return sbjnOrgCode;
    }

    public void setSbjnOrgCode(String sbjnOrgCode) {
        this.sbjnOrgCode = sbjnOrgCode;
    }
    public String getIsMove() {
        return isMove;
    }

    public void setIsMove(String isMove) {
        this.isMove = isMove;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public Long getGzffOrgId() {
        return gzffOrgId;
    }

    public void setGzffOrgId(Long gzffOrgId) {
        this.gzffOrgId = gzffOrgId;
    }
    public String getGzffOrgName() {
        return gzffOrgName;
    }

    public void setGzffOrgName(String gzffOrgName) {
        this.gzffOrgName = gzffOrgName;
    }
    public String getGzffOrgCode() {
        return gzffOrgCode;
    }

    public void setGzffOrgCode(String gzffOrgCode) {
        this.gzffOrgCode = gzffOrgCode;
    }
    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }
    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }
    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }
    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }
    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }
    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }
    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }
    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }
    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }
    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }
    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }
    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }
    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }
    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }
    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }
    public BigDecimal getOrgSalaryMny() {
        return orgSalaryMny;
    }

    public void setOrgSalaryMny(BigDecimal orgSalaryMny) {
        this.orgSalaryMny = orgSalaryMny;
    }
    public BigDecimal getOrgsSalaryMny() {
        return orgsSalaryMny;
    }

    public void setOrgsSalaryMny(BigDecimal orgsSalaryMny) {
        this.orgsSalaryMny = orgsSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getTaxYfmsMny() {
        return taxYfmsMny;
    }

    public void setTaxYfmsMny(BigDecimal taxYfmsMny) {
        this.taxYfmsMny = taxYfmsMny;
    }
}

==> ejc-salary-impl-3.0.0-20250912.045436-186-sources.jar: com/ejianc/business/salary/bean/PayableDetailEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发工资上传明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_payable_detail")
public class PayableDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="payable_id")
    private Long payableId; // 主表id
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 员工主键
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 员工名称
    @TableField(value="detail_employee_code")
    private String detailEmployeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="job_type")
    private String jobType; // 岗位性质
    @TableField(value="detail_org_id")
    private Long detailOrgId; // 单位id
    @TableField(value="detail_org_name")
    private String detailOrgName; // 单位名称
    @TableField(value="detail_org_code")
    private String detailOrgCode; // 单位编码
    @TableField(value="job")
    private String job; // 岗位
    @TableField(value="dept")
    private String dept; // 部门
    @TableField(value="job_level")
    private String jobLevel; // 岗级
    @TableField(value="sbjn_org_name")
    private String sbjnOrgName; // 社保缴纳单位名称
    @TableField(value="sbjn_org_code")
    private String sbjnOrgCode; // 社保缴纳单位编码
    @TableField(value="is_move")
    private String isMove; // 本月是否发生调动：1是,2-否
    @TableField(value="sbcd_org_id")
    private Long sbcdOrgId; // 社保承担单位id
    @TableField(value="sbcd_org_name")
    private String sbcdOrgName; // 社保承担单位名称
    @TableField(value="sbcd_org_code")
    private String sbcdOrgCode; // 社保承担单位编码
    @TableField(value="gzff_org_id")
    private Long gzffOrgId; // 工资发放单位id
    @TableField(value="gzff_org_name")
    private String gzffOrgName; // 工资发放单位名称
    @TableField(value="gzff_org_code")
    private String gzffOrgCode; // 工资发放单位编码
    @TableField(value="un_write_off_mny")
    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    @TableField(value="write_off_mny")
    private BigDecimal writeOffMny; // 本次核销金额
    @TableField(value="yfjs_mny")
    private BigDecimal yfjsMny; // 应发计税
    @TableField(value="yfms_mny")
    private BigDecimal yfmsMny; // 应发免税
    @TableField(value="job_mny")
    private BigDecimal jobMny; // 岗位工资
    @TableField(value="performance_mny")
    private BigDecimal performanceMny; // 绩效工资
    @TableField(value="work_year_mny")
    private BigDecimal workYearMny; // 司龄补贴
    @TableField(value="work_type_mny")
    private BigDecimal workTypeMny; // 职称补贴
    @TableField(value="certificate_mny")
    private BigDecimal certificateMny; // 证书补贴
    @TableField(value="travel_mny")
    private BigDecimal travelMny; // 派驻补贴
    @TableField(value="traffic_mny")
    private BigDecimal trafficMny; // 交通补贴
    @TableField(value="meal_mny")
    private BigDecimal mealMny; // 餐补
    @TableField(value="benefit_mny")
    private BigDecimal benefitMny; // 福利费
    @TableField(value="holiday_mny")
    private BigDecimal holidayMny; // 过节费
    @TableField(value="year_end_mny")
    private BigDecimal yearEndMny; // 年终奖
    @TableField(value="overtime_mny")
    private BigDecimal overtimeMny; // 加班费
    @TableField(value="add_mny")
    private BigDecimal addMny; // 补款
    @TableField(value="button_mny")
    private BigDecimal buttonMny; // 扣款
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 工资合计
    @TableField(value="yf_salary_mny")
    private BigDecimal yfSalaryMny; // 应发工资
    @TableField(value="yfms_salary_mny")
    private BigDecimal yfmsSalaryMny; // 应发+免税
    @TableField(value="org_salary_mny")
    private BigDecimal orgSalaryMny; // 个人本单位累计
    @TableField(value="orgs_salary_mny")
    private BigDecimal orgsSalaryMny; // 个人所有单位累计
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="tax_yfms_mny")
    private BigDecimal taxYfmsMny; // 个税计算、工资单应发免税

    @TableField(value="detail_collect_status")
    private Integer detailCollectStatus; // 汇总状态（0-未汇总，1--已汇总,2-被驳回）

    @TableField(value="sbcd_company_id")
    private Long sbcdCompanyId; // 社保承担公司id
    @TableField(value="sbcd_company_code")
    private String sbcdCompanyCode; // 社保承担公司编号
    @TableField(value="sbcd_company_name")
    private String sbcdCompanyName; // 社保承担公司

    @TableField(value="yfjscw_mny")
    private BigDecimal yfjscwMny; // 应发计税财务
    @TableField(value="yfmscw_mny")
    private BigDecimal yfmscwMny; // 应发免税财务

    @TableField(value="work_days_last_month")
    private BigDecimal workDaysLastMonth; //


    public BigDecimal getWorkDaysLastMonth() {
        return workDaysLastMonth;
    }

    public void setWorkDaysLastMonth(BigDecimal workDaysLastMonth) {
        this.workDaysLastMonth = workDaysLastMonth;
    }

    public BigDecimal getYfjscwMny() {
        return yfjscwMny;
    }

    public void setYfjscwMny(BigDecimal yfjscwMny) {
        this.yfjscwMny = yfjscwMny;
    }

    public BigDecimal getYfmscwMny() {
        return yfmscwMny;
    }

    public void setYfmscwMny(BigDecimal yfmscwMny) {
        this.yfmscwMny = yfmscwMny;
    }

    public Long getSbcdCompanyId() {
        return sbcdCompanyId;
    }

    public void setSbcdCompanyId(Long sbcdCompanyId) {
        this.sbcdCompanyId = sbcdCompanyId;
    }

    public String getSbcdCompanyCode() {
        return sbcdCompanyCode;
    }

    public void setSbcdCompanyCode(String sbcdCompanyCode) {
        this.sbcdCompanyCode = sbcdCompanyCode;
    }

    public String getSbcdCompanyName() {
        return sbcdCompanyName;
    }

    public void setSbcdCompanyName(String sbcdCompanyName) {
        this.sbcdCompanyName = sbcdCompanyName;
    }

    public Integer getDetailCollectStatus() {
        return detailCollectStatus;
    }

    public void setDetailCollectStatus(Integer detailCollectStatus) {
        this.detailCollectStatus = detailCollectStatus;
    }

    public Long getPayableId() {
        return payableId;
    }

    public void setPayableId(Long payableId) {
        this.payableId = payableId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getJobType() {
        return jobType;
    }

    public void setJobType(String jobType) {
        this.jobType = jobType;
    }
    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }
    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }
    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getDept() {
        return dept;
    }

    public void setDept(String dept) {
        this.dept = dept;
    }
    public String getJobLevel() {
        return jobLevel;
    }

    public void setJobLevel(String jobLevel) {
        this.jobLevel = jobLevel;
    }
    public String getSbjnOrgName() {
        return sbjnOrgName;
    }

    public void setSbjnOrgName(String sbjnOrgName) {
        this.sbjnOrgName = sbjnOrgName;
    }
    public String getSbjnOrgCode() {
        return sbjnOrgCode;
    }

    public void setSbjnOrgCode(String sbjnOrgCode) {
        this.sbjnOrgCode = sbjnOrgCode;
    }
    public String getIsMove() {
        return isMove;
    }

    public void setIsMove(String isMove) {
        this.isMove = isMove;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public Long getGzffOrgId() {
        return gzffOrgId;
    }

    public void setGzffOrgId(Long gzffOrgId) {
        this.gzffOrgId = gzffOrgId;
    }
    public String getGzffOrgName() {
        return gzffOrgName;
    }

    public void setGzffOrgName(String gzffOrgName) {
        this.gzffOrgName = gzffOrgName;
    }
    public String getGzffOrgCode() {
        return gzffOrgCode;
    }

    public void setGzffOrgCode(String gzffOrgCode) {
        this.gzffOrgCode = gzffOrgCode;
    }
    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }
    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }
    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }
    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }
    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }
    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }
    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }
    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }
    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }
    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }
    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }
    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }
    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }
    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }
    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }
    public BigDecimal getOrgSalaryMny() {
        return orgSalaryMny;
    }

    public void setOrgSalaryMny(BigDecimal orgSalaryMny) {
        this.orgSalaryMny = orgSalaryMny;
    }
    public BigDecimal getOrgsSalaryMny() {
        return orgsSalaryMny;
    }

    public void setOrgsSalaryMny(BigDecimal orgsSalaryMny) {
        this.orgsSalaryMny = orgsSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getTaxYfmsMny() {
        return taxYfmsMny;
    }

    public void setTaxYfmsMny(BigDecimal taxYfmsMny) {
        this.taxYfmsMny = taxYfmsMny;
    }
}
